# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'observatories.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormObservatory(object):
    def setupUi(self, FormObservatory):
        FormObservatory.setObjectName("FormObservatory")
        FormObservatory.resize(400, 215)
        self.gridLayout_2 = QtWidgets.QGridLayout(FormObservatory)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.comboBoxObservatory = QtWidgets.QComboBox(FormObservatory)
        self.comboBoxObservatory.setObjectName("comboBoxObservatory")
        self.comboBoxObservatory.addItem("")
        self.gridLayout_2.addWidget(self.comboBoxObservatory, 0, 0, 1, 3)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.lineEditName = QtWidgets.QLineEdit(FormObservatory)
        self.lineEditName.setObjectName("lineEditName")
        self.gridLayout.addWidget(self.lineEditName, 0, 0, 1, 2)
        self.label = QtWidgets.QLabel(FormObservatory)
        self.label.setMinimumSize(QtCore.QSize(91, 18))
        self.label.setMaximumSize(QtCore.QSize(91, 18))
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 1, 0, 1, 1)
        self.doubleSpinBoxLatitude = QtWidgets.QDoubleSpinBox(FormObservatory)
        self.doubleSpinBoxLatitude.setMinimum(-90.0)
        self.doubleSpinBoxLatitude.setMaximum(90.0)
        self.doubleSpinBoxLatitude.setObjectName("doubleSpinBoxLatitude")
        self.gridLayout.addWidget(self.doubleSpinBoxLatitude, 1, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(FormObservatory)
        self.label_2.setMinimumSize(QtCore.QSize(91, 18))
        self.label_2.setMaximumSize(QtCore.QSize(91, 18))
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 2, 0, 1, 1)
        self.doubleSpinBoxLongitude = QtWidgets.QDoubleSpinBox(FormObservatory)
        self.doubleSpinBoxLongitude.setMinimum(-180.0)
        self.doubleSpinBoxLongitude.setMaximum(180.0)
        self.doubleSpinBoxLongitude.setProperty("value", 0.0)
        self.doubleSpinBoxLongitude.setObjectName("doubleSpinBoxLongitude")
        self.gridLayout.addWidget(self.doubleSpinBoxLongitude, 2, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(FormObservatory)
        self.label_3.setMinimumSize(QtCore.QSize(91, 18))
        self.label_3.setMaximumSize(QtCore.QSize(91, 18))
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 3, 0, 1, 1)
        self.doubleSpinBoxAltitude = QtWidgets.QDoubleSpinBox(FormObservatory)
        self.doubleSpinBoxAltitude.setMinimum(0.0)
        self.doubleSpinBoxAltitude.setMaximum(1e+56)
        self.doubleSpinBoxAltitude.setProperty("value", 0.0)
        self.doubleSpinBoxAltitude.setObjectName("doubleSpinBoxAltitude")
        self.gridLayout.addWidget(self.doubleSpinBoxAltitude, 3, 1, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 1, 0, 1, 3)
        spacerItem = QtWidgets.QSpacerItem(20, 1, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem, 2, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(291, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem1, 3, 0, 1, 1)
        self.pushButtonRremove = QtWidgets.QPushButton(FormObservatory)
        self.pushButtonRremove.setEnabled(False)
        self.pushButtonRremove.setObjectName("pushButtonRremove")
        self.gridLayout_2.addWidget(self.pushButtonRremove, 3, 1, 1, 1)
        self.pushButtonSave = QtWidgets.QPushButton(FormObservatory)
        self.pushButtonSave.setObjectName("pushButtonSave")
        self.gridLayout_2.addWidget(self.pushButtonSave, 3, 2, 1, 1)

        self.retranslateUi(FormObservatory)
        QtCore.QMetaObject.connectSlotsByName(FormObservatory)

    def retranslateUi(self, FormObservatory):
        _translate = QtCore.QCoreApplication.translate
        FormObservatory.setWindowTitle(_translate("FormObservatory", "Observatories"))
        self.comboBoxObservatory.setItemText(0, _translate("FormObservatory", "New"))
        self.lineEditName.setPlaceholderText(_translate("FormObservatory", "Name"))
        self.label.setText(_translate("FormObservatory", "Latitude"))
        self.label_2.setText(_translate("FormObservatory", "Longitude"))
        self.label_3.setText(_translate("FormObservatory", "Altitude"))
        self.pushButtonRremove.setText(_translate("FormObservatory", "Remove"))
        self.pushButtonSave.setText(_translate("FormObservatory", "Add/Update"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormObservatory = QtWidgets.QWidget()
    ui = Ui_FormObservatory()
    ui.setupUi(FormObservatory)
    FormObservatory.show()
    sys.exit(app.exec_())
