# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'align.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormAlign(object):
    def setupUi(self, FormAlign):
        FormAlign.setObjectName("FormAlign")
        FormAlign.resize(419, 197)
        self.gridLayout_2 = QtWidgets.QGridLayout(FormAlign)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label_4 = QtWidgets.QLabel(FormAlign)
        self.label_4.setMinimumSize(QtCore.QSize(154, 26))
        self.label_4.setMaximumSize(QtCore.QSize(154, 26))
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 0, 0, 1, 1)
        self.comboBoxReference = QtWidgets.QComboBox(FormAlign)
        self.comboBoxReference.setObjectName("comboBoxReference")
        self.gridLayout.addWidget(self.comboBoxReference, 0, 1, 1, 1)
        self.pushButtonShow = QtWidgets.QPushButton(FormAlign)
        self.pushButtonShow.setMinimumSize(QtCore.QSize(80, 26))
        self.pushButtonShow.setMaximumSize(QtCore.QSize(80, 26))
        self.pushButtonShow.setObjectName("pushButtonShow")
        self.gridLayout.addWidget(self.pushButtonShow, 0, 2, 1, 1)
        self.label = QtWidgets.QLabel(FormAlign)
        self.label.setMinimumSize(QtCore.QSize(154, 27))
        self.label.setMaximumSize(QtCore.QSize(154, 27))
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 1, 0, 1, 1)
        self.spinBoxMaxControlPoint = QtWidgets.QSpinBox(FormAlign)
        self.spinBoxMaxControlPoint.setProperty("value", 50)
        self.spinBoxMaxControlPoint.setObjectName("spinBoxMaxControlPoint")
        self.gridLayout.addWidget(self.spinBoxMaxControlPoint, 1, 1, 1, 2)
        self.label_2 = QtWidgets.QLabel(FormAlign)
        self.label_2.setMinimumSize(QtCore.QSize(154, 27))
        self.label_2.setMaximumSize(QtCore.QSize(154, 27))
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 2, 0, 1, 1)
        self.doubleSpinDetectionSigma = QtWidgets.QDoubleSpinBox(FormAlign)
        self.doubleSpinDetectionSigma.setMinimum(-1e+42)
        self.doubleSpinDetectionSigma.setMaximum(1e+42)
        self.doubleSpinDetectionSigma.setProperty("value", 5.0)
        self.doubleSpinDetectionSigma.setObjectName("doubleSpinDetectionSigma")
        self.gridLayout.addWidget(self.doubleSpinDetectionSigma, 2, 1, 1, 2)
        self.label_3 = QtWidgets.QLabel(FormAlign)
        self.label_3.setMinimumSize(QtCore.QSize(154, 27))
        self.label_3.setMaximumSize(QtCore.QSize(154, 27))
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 3, 0, 1, 1)
        self.spinBoxMinArea = QtWidgets.QSpinBox(FormAlign)
        self.spinBoxMinArea.setProperty("value", 50)
        self.spinBoxMinArea.setObjectName("spinBoxMinArea")
        self.gridLayout.addWidget(self.spinBoxMinArea, 3, 1, 1, 2)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 2)
        spacerItem = QtWidgets.QSpacerItem(20, 42, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem, 1, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(211, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem1, 2, 0, 1, 1)
        self.pushButtonGO = QtWidgets.QPushButton(FormAlign)
        self.pushButtonGO.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setObjectName("pushButtonGO")
        self.gridLayout_2.addWidget(self.pushButtonGO, 2, 1, 1, 1)

        self.retranslateUi(FormAlign)
        QtCore.QMetaObject.connectSlotsByName(FormAlign)

    def retranslateUi(self, FormAlign):
        _translate = QtCore.QCoreApplication.translate
        FormAlign.setWindowTitle(_translate("FormAlign", "Align"))
        self.label_4.setText(_translate("FormAlign", "Reference"))
        self.pushButtonShow.setText(_translate("FormAlign", "Show"))
        self.label.setText(_translate("FormAlign", "Max Control Points"))
        self.label_2.setText(_translate("FormAlign", "Detection Sigma"))
        self.label_3.setText(_translate("FormAlign", "Min Area"))
        self.pushButtonGO.setText(_translate("FormAlign", ":go"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormAlign = QtWidgets.QWidget()
    ui = Ui_FormAlign()
    ui.setupUi(FormAlign)
    FormAlign.show()
    sys.exit(app.exec_())
