from .about import Ui_FormAbout
from .align import Ui_FormAlign
from .arithmetic import Ui_FormArithmetic
from .bin import Ui_FormBin
from .ccdproc import Ui_FormCCDPROC
from .combine import Ui_FormCombine
from .cosmic_cleaner import Ui_FormCosmicCleaner
from .crop import Ui_FormCrop
from .display import Ui_FormDisplay
from .header import Ui_FormHeader
from .header_calculator import Ui_FormHeaderCalculator
from .hedit import Ui_FormHedit
from .hselect import Ui_FormHSelect
from .log import Ui_FormLog
from .main import Ui_MainWindow
from .observatories import Ui_FormObservatory
from .photometry import Ui_FormPhotometry
from .rotate import Ui_FormRotate
from .settings import Ui_FormSettings
from .shift import Ui_FormShift
from .statics import Ui_FormStatics
from .wcs import Ui_FormWCS
