# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1245, 1002)
        MainWindow.setMinimumSize(QtCore.QSize(800, 600))
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.playGround = QtWidgets.QMdiArea(self.centralwidget)
        self.playGround.setObjectName("playGround")
        self.gridLayout_2.addWidget(self.playGround, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.dockWidget_2 = QtWidgets.QDockWidget(MainWindow)
        self.dockWidget_2.setFloating(False)
        self.dockWidget_2.setFeatures(QtWidgets.QDockWidget.DockWidgetFloatable|QtWidgets.QDockWidget.DockWidgetMovable)
        self.dockWidget_2.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.dockWidget_2.setObjectName("dockWidget_2")
        self.dockWidgetContents_2 = QtWidgets.QWidget()
        self.dockWidgetContents_2.setObjectName("dockWidgetContents_2")
        self.gridLayout = QtWidgets.QGridLayout(self.dockWidgetContents_2)
        self.gridLayout.setObjectName("gridLayout")
        self.treeWidget = QtWidgets.QTreeWidget(self.dockWidgetContents_2)
        self.treeWidget.setEditTriggers(QtWidgets.QAbstractItemView.DoubleClicked|QtWidgets.QAbstractItemView.EditKeyPressed)
        self.treeWidget.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.treeWidget.setObjectName("treeWidget")
        self.gridLayout.addWidget(self.treeWidget, 0, 1, 1, 1)
        self.dockWidget_2.setWidget(self.dockWidgetContents_2)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(1), self.dockWidget_2)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1245, 23))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuSettings = QtWidgets.QMenu(self.menubar)
        self.menuSettings.setObjectName("menuSettings")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.actionDefaults = QtWidgets.QAction(MainWindow)
        self.actionDefaults.setObjectName("actionDefaults")
        self.actionAdd = QtWidgets.QAction(MainWindow)
        self.actionAdd.setObjectName("actionAdd")
        self.actionSubtract = QtWidgets.QAction(MainWindow)
        self.actionSubtract.setObjectName("actionSubtract")
        self.actionMultiply = QtWidgets.QAction(MainWindow)
        self.actionMultiply.setObjectName("actionMultiply")
        self.actionDivide = QtWidgets.QAction(MainWindow)
        self.actionDivide.setObjectName("actionDivide")
        self.actionPower = QtWidgets.QAction(MainWindow)
        self.actionPower.setObjectName("actionPower")
        self.actionMod = QtWidgets.QAction(MainWindow)
        self.actionMod.setObjectName("actionMod")
        self.actionStatics = QtWidgets.QAction(MainWindow)
        self.actionStatics.setObjectName("actionStatics")
        self.actionHedit = QtWidgets.QAction(MainWindow)
        self.actionHedit.setObjectName("actionHedit")
        self.actionCosmic_Cleaner = QtWidgets.QAction(MainWindow)
        self.actionCosmic_Cleaner.setObjectName("actionCosmic_Cleaner")
        self.actionAbsolute = QtWidgets.QAction(MainWindow)
        self.actionAbsolute.setObjectName("actionAbsolute")
        self.actionBackground = QtWidgets.QAction(MainWindow)
        self.actionBackground.setObjectName("actionBackground")
        self.actionsep = QtWidgets.QAction(MainWindow)
        self.actionsep.setObjectName("actionsep")
        self.actiondaofind = QtWidgets.QAction(MainWindow)
        self.actiondaofind.setObjectName("actiondaofind")
        self.actionAlign = QtWidgets.QAction(MainWindow)
        self.actionAlign.setObjectName("actionAlign")
        self.actionSolve = QtWidgets.QAction(MainWindow)
        self.actionSolve.setObjectName("actionSolve")
        self.actionShift = QtWidgets.QAction(MainWindow)
        self.actionShift.setObjectName("actionShift")
        self.actionRotate = QtWidgets.QAction(MainWindow)
        self.actionRotate.setObjectName("actionRotate")
        self.actionCrop = QtWidgets.QAction(MainWindow)
        self.actionCrop.setObjectName("actionCrop")
        self.actionBin = QtWidgets.QAction(MainWindow)
        self.actionBin.setObjectName("actionBin")
        self.actionShow = QtWidgets.QAction(MainWindow)
        self.actionShow.setObjectName("actionShow")
        self.actionCombine = QtWidgets.QAction(MainWindow)
        self.actionCombine.setObjectName("actionCombine")
        self.actionCalibration_2 = QtWidgets.QAction(MainWindow)
        self.actionCalibration_2.setObjectName("actionCalibration_2")
        self.actionCombine_3 = QtWidgets.QAction(MainWindow)
        self.actionCombine_3.setObjectName("actionCombine_3")
        self.actionZero_Combine = QtWidgets.QAction(MainWindow)
        self.actionZero_Combine.setObjectName("actionZero_Combine")
        self.actionDark_Combine = QtWidgets.QAction(MainWindow)
        self.actionDark_Combine.setObjectName("actionDark_Combine")
        self.actionFlat_Combine = QtWidgets.QAction(MainWindow)
        self.actionFlat_Combine.setObjectName("actionFlat_Combine")
        self.actionZero_Correction = QtWidgets.QAction(MainWindow)
        self.actionZero_Correction.setObjectName("actionZero_Correction")
        self.actionDark_Correction = QtWidgets.QAction(MainWindow)
        self.actionDark_Correction.setObjectName("actionDark_Correction")
        self.actionFlat_Correction = QtWidgets.QAction(MainWindow)
        self.actionFlat_Correction.setObjectName("actionFlat_Correction")
        self.actionPixel_to_World = QtWidgets.QAction(MainWindow)
        self.actionPixel_to_World.setObjectName("actionPixel_to_World")
        self.actionWorld_to_Pixel = QtWidgets.QAction(MainWindow)
        self.actionWorld_to_Pixel.setObjectName("actionWorld_to_Pixel")
        self.actionsep_2 = QtWidgets.QAction(MainWindow)
        self.actionsep_2.setObjectName("actionsep_2")
        self.actionphotutils = QtWidgets.QAction(MainWindow)
        self.actionphotutils.setObjectName("actionphotutils")
        self.actionAll = QtWidgets.QAction(MainWindow)
        self.actionAll.setObjectName("actionAll")
        self.actionAdd_2 = QtWidgets.QAction(MainWindow)
        self.actionAdd_2.setObjectName("actionAdd_2")
        self.actionRemove = QtWidgets.QAction(MainWindow)
        self.actionRemove.setObjectName("actionRemove")
        self.actionQuit = QtWidgets.QAction(MainWindow)
        self.actionQuit.setObjectName("actionQuit")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionHeader_Calculator = QtWidgets.QAction(MainWindow)
        self.actionHeader_Calculator.setObjectName("actionHeader_Calculator")
        self.actionObservatories = QtWidgets.QAction(MainWindow)
        self.actionObservatories.setObjectName("actionObservatories")
        self.actionLog = QtWidgets.QAction(MainWindow)
        self.actionLog.setObjectName("actionLog")
        self.actionccdproc = QtWidgets.QAction(MainWindow)
        self.actionccdproc.setObjectName("actionccdproc")
        self.actionPhotometry = QtWidgets.QAction(MainWindow)
        self.actionPhotometry.setObjectName("actionPhotometry")
        self.actionSettings = QtWidgets.QAction(MainWindow)
        self.actionSettings.setObjectName("actionSettings")
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit)
        self.menuSettings.addAction(self.actionSettings)
        self.menuSettings.addAction(self.actionObservatories)
        self.menuHelp.addAction(self.actionLog)
        self.menuHelp.addAction(self.actionAbout)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuSettings.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MYRaf V3"))
        self.treeWidget.headerItem().setText(0, _translate("MainWindow", "key"))
        self.treeWidget.headerItem().setText(1, _translate("MainWindow", "Value"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuSettings.setTitle(_translate("MainWindow", "Settings"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.actionDefaults.setText(_translate("MainWindow", "Defaults..."))
        self.actionAdd.setText(_translate("MainWindow", "Add..."))
        self.actionSubtract.setText(_translate("MainWindow", "Subtract..."))
        self.actionMultiply.setText(_translate("MainWindow", "Multiply..."))
        self.actionDivide.setText(_translate("MainWindow", "Divide..."))
        self.actionPower.setText(_translate("MainWindow", "Power..."))
        self.actionMod.setText(_translate("MainWindow", "Mod..."))
        self.actionStatics.setText(_translate("MainWindow", "Statics..."))
        self.actionHedit.setText(_translate("MainWindow", "Hedit..."))
        self.actionCosmic_Cleaner.setText(_translate("MainWindow", "Cosmic Cleaner..."))
        self.actionAbsolute.setText(_translate("MainWindow", "Absolute..."))
        self.actionBackground.setText(_translate("MainWindow", "Background..."))
        self.actionsep.setText(_translate("MainWindow", "sep..."))
        self.actiondaofind.setText(_translate("MainWindow", "daofind..."))
        self.actionAlign.setText(_translate("MainWindow", "Align..."))
        self.actionSolve.setText(_translate("MainWindow", "Solve..."))
        self.actionShift.setText(_translate("MainWindow", "Shift..."))
        self.actionRotate.setText(_translate("MainWindow", "Rotate..."))
        self.actionCrop.setText(_translate("MainWindow", "Crop..."))
        self.actionBin.setText(_translate("MainWindow", "Bin..."))
        self.actionShow.setText(_translate("MainWindow", "Show..."))
        self.actionCombine.setText(_translate("MainWindow", "Combine"))
        self.actionCalibration_2.setText(_translate("MainWindow", "Calibration"))
        self.actionCombine_3.setText(_translate("MainWindow", "Combine..."))
        self.actionZero_Combine.setText(_translate("MainWindow", "Zero Combine..."))
        self.actionDark_Combine.setText(_translate("MainWindow", "Dark Combine..."))
        self.actionFlat_Combine.setText(_translate("MainWindow", "Flat Combine..."))
        self.actionZero_Correction.setText(_translate("MainWindow", "Zero Correction..."))
        self.actionDark_Correction.setText(_translate("MainWindow", "Dark Correction..."))
        self.actionFlat_Correction.setText(_translate("MainWindow", "Flat Correction..."))
        self.actionPixel_to_World.setText(_translate("MainWindow", "Pixel to World..."))
        self.actionWorld_to_Pixel.setText(_translate("MainWindow", "World to Pixel..."))
        self.actionsep_2.setText(_translate("MainWindow", "sep..."))
        self.actionphotutils.setText(_translate("MainWindow", "photutils..."))
        self.actionAll.setText(_translate("MainWindow", "All..."))
        self.actionAdd_2.setText(_translate("MainWindow", "Add"))
        self.actionRemove.setText(_translate("MainWindow", "Remove"))
        self.actionQuit.setText(_translate("MainWindow", "Quit"))
        self.actionAbout.setText(_translate("MainWindow", "About"))
        self.actionHeader_Calculator.setText(_translate("MainWindow", "Header Calculator..."))
        self.actionObservatories.setText(_translate("MainWindow", "Observatories"))
        self.actionLog.setText(_translate("MainWindow", "Log"))
        self.actionccdproc.setText(_translate("MainWindow", "ccdproc"))
        self.actionPhotometry.setText(_translate("MainWindow", "Photometry"))
        self.actionSettings.setText(_translate("MainWindow", "Settings"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
