# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'photometry.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormPhotometry(object):
    def setupUi(self, FormPhotometry):
        FormPhotometry.setObjectName("FormPhotometry")
        FormPhotometry.resize(834, 807)
        self.gridLayout_4 = QtWidgets.QGridLayout(FormPhotometry)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.pushButtonGO = QtWidgets.QPushButton(FormPhotometry)
        self.pushButtonGO.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setObjectName("pushButtonGO")
        self.gridLayout_4.addWidget(self.pushButtonGO, 1, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(848, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_4.addItem(spacerItem, 1, 0, 1, 1)
        self.tabWidget = QtWidgets.QTabWidget(FormPhotometry)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.tab)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab)
        self.groupBox_2.setMinimumSize(QtCore.QSize(241, 0))
        self.groupBox_2.setMaximumSize(QtCore.QSize(241, 16777215))
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout.setObjectName("gridLayout")
        self.tableWidgetCoordinates = QtWidgets.QTableWidget(self.groupBox_2)
        self.tableWidgetCoordinates.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tableWidgetCoordinates.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableWidgetCoordinates.setObjectName("tableWidgetCoordinates")
        self.tableWidgetCoordinates.setColumnCount(2)
        self.tableWidgetCoordinates.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetCoordinates.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetCoordinates.setHorizontalHeaderItem(1, item)
        self.gridLayout.addWidget(self.tableWidgetCoordinates, 0, 0, 1, 1)
        self.gridLayout_6.addWidget(self.groupBox_2, 0, 0, 2, 1)
        self.labelRa = QtWidgets.QLabel(self.tab)
        self.labelRa.setMinimumSize(QtCore.QSize(0, 19))
        self.labelRa.setMaximumSize(QtCore.QSize(16777215, 19))
        self.labelRa.setText("")
        self.labelRa.setObjectName("labelRa")
        self.gridLayout_6.addWidget(self.labelRa, 0, 1, 1, 1)
        self.labelDec = QtWidgets.QLabel(self.tab)
        self.labelDec.setMinimumSize(QtCore.QSize(0, 19))
        self.labelDec.setMaximumSize(QtCore.QSize(16777215, 19))
        self.labelDec.setText("")
        self.labelDec.setObjectName("labelDec")
        self.gridLayout_6.addWidget(self.labelDec, 0, 2, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.tab)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_6.addWidget(self.groupBox, 1, 1, 1, 2)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.tab_2)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.label = QtWidgets.QLabel(self.tab_2)
        self.label.setObjectName("label")
        self.gridLayout_10.addWidget(self.label, 0, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.tab_2)
        self.label_2.setObjectName("label_2")
        self.gridLayout_10.addWidget(self.label_2, 2, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab_2)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.doubleSpinBoxApertureRadius = QtWidgets.QDoubleSpinBox(self.groupBox_3)
        self.doubleSpinBoxApertureRadius.setMinimum(1.0)
        self.doubleSpinBoxApertureRadius.setMaximum(9999999.0)
        self.doubleSpinBoxApertureRadius.setObjectName("doubleSpinBoxApertureRadius")
        self.gridLayout_3.addWidget(self.doubleSpinBoxApertureRadius, 0, 0, 1, 1)
        self.pushButtonAddToRadii = QtWidgets.QPushButton(self.groupBox_3)
        self.pushButtonAddToRadii.setMaximumSize(QtCore.QSize(80, 26))
        self.pushButtonAddToRadii.setObjectName("pushButtonAddToRadii")
        self.gridLayout_3.addWidget(self.pushButtonAddToRadii, 0, 1, 1, 1)
        self.listWidgetApertureRadii = QtWidgets.QListWidget(self.groupBox_3)
        self.listWidgetApertureRadii.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.listWidgetApertureRadii.setObjectName("listWidgetApertureRadii")
        self.gridLayout_3.addWidget(self.listWidgetApertureRadii, 1, 0, 1, 2)
        self.gridLayout_10.addWidget(self.groupBox_3, 4, 0, 1, 2)
        self.groupBox_4 = QtWidgets.QGroupBox(self.tab_2)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.listWidgetHeaders = QtWidgets.QListWidget(self.groupBox_4)
        self.listWidgetHeaders.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.listWidgetHeaders.setObjectName("listWidgetHeaders")
        self.gridLayout_2.addWidget(self.listWidgetHeaders, 0, 0, 4, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 56, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem1, 0, 1, 1, 1)
        self.listWidgetHeadersToExtract = QtWidgets.QListWidget(self.groupBox_4)
        self.listWidgetHeadersToExtract.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.listWidgetHeadersToExtract.setObjectName("listWidgetHeadersToExtract")
        self.gridLayout_2.addWidget(self.listWidgetHeadersToExtract, 0, 2, 4, 1)
        self.pushButtonAddToHeaderToExtract = QtWidgets.QPushButton(self.groupBox_4)
        self.pushButtonAddToHeaderToExtract.setObjectName("pushButtonAddToHeaderToExtract")
        self.gridLayout_2.addWidget(self.pushButtonAddToHeaderToExtract, 1, 1, 1, 1)
        self.pushButtonRemoveFromHeaderToExtract = QtWidgets.QPushButton(self.groupBox_4)
        self.pushButtonRemoveFromHeaderToExtract.setObjectName("pushButtonRemoveFromHeaderToExtract")
        self.gridLayout_2.addWidget(self.pushButtonRemoveFromHeaderToExtract, 2, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 57, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem2, 3, 1, 1, 1)
        self.gridLayout_10.addWidget(self.groupBox_4, 5, 0, 1, 2)
        self.tabWidget_2 = QtWidgets.QTabWidget(self.tab_2)
        self.tabWidget_2.setObjectName("tabWidget_2")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.tab_3)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.gridLayout_5 = QtWidgets.QGridLayout()
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.label_3 = QtWidgets.QLabel(self.tab_3)
        self.label_3.setMinimumSize(QtCore.QSize(100, 0))
        self.label_3.setMaximumSize(QtCore.QSize(100, 16777215))
        self.label_3.setObjectName("label_3")
        self.gridLayout_5.addWidget(self.label_3, 0, 0, 1, 1)
        self.doubleSpinBoxSexSigma = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.doubleSpinBoxSexSigma.setMinimum(1.0)
        self.doubleSpinBoxSexSigma.setProperty("value", 5.0)
        self.doubleSpinBoxSexSigma.setObjectName("doubleSpinBoxSexSigma")
        self.gridLayout_5.addWidget(self.doubleSpinBoxSexSigma, 0, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.tab_3)
        self.label_4.setMinimumSize(QtCore.QSize(100, 0))
        self.label_4.setMaximumSize(QtCore.QSize(100, 16777215))
        self.label_4.setObjectName("label_4")
        self.gridLayout_5.addWidget(self.label_4, 1, 0, 1, 1)
        self.doubleSpinBoxSexMinimumArea = QtWidgets.QDoubleSpinBox(self.tab_3)
        self.doubleSpinBoxSexMinimumArea.setMinimum(1.0)
        self.doubleSpinBoxSexMinimumArea.setProperty("value", 5.0)
        self.doubleSpinBoxSexMinimumArea.setObjectName("doubleSpinBoxSexMinimumArea")
        self.gridLayout_5.addWidget(self.doubleSpinBoxSexMinimumArea, 1, 1, 1, 1)
        self.gridLayout_7.addLayout(self.gridLayout_5, 0, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(20, 33, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_7.addItem(spacerItem3, 1, 0, 1, 1)
        self.tabWidget_2.addTab(self.tab_3, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.tab_4)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.gridLayout_8 = QtWidgets.QGridLayout()
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.label_5 = QtWidgets.QLabel(self.tab_4)
        self.label_5.setMinimumSize(QtCore.QSize(100, 0))
        self.label_5.setMaximumSize(QtCore.QSize(100, 16777215))
        self.label_5.setObjectName("label_5")
        self.gridLayout_8.addWidget(self.label_5, 0, 0, 1, 1)
        self.doubleSpinBoxDAOFindSigma = QtWidgets.QDoubleSpinBox(self.tab_4)
        self.doubleSpinBoxDAOFindSigma.setMinimum(1.0)
        self.doubleSpinBoxDAOFindSigma.setProperty("value", 3.0)
        self.doubleSpinBoxDAOFindSigma.setObjectName("doubleSpinBoxDAOFindSigma")
        self.gridLayout_8.addWidget(self.doubleSpinBoxDAOFindSigma, 0, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.tab_4)
        self.label_6.setMinimumSize(QtCore.QSize(100, 0))
        self.label_6.setMaximumSize(QtCore.QSize(100, 16777215))
        self.label_6.setObjectName("label_6")
        self.gridLayout_8.addWidget(self.label_6, 1, 0, 1, 1)
        self.doubleSpinBoxDAOFindFWHM = QtWidgets.QDoubleSpinBox(self.tab_4)
        self.doubleSpinBoxDAOFindFWHM.setMinimum(1.0)
        self.doubleSpinBoxDAOFindFWHM.setProperty("value", 3.0)
        self.doubleSpinBoxDAOFindFWHM.setObjectName("doubleSpinBoxDAOFindFWHM")
        self.gridLayout_8.addWidget(self.doubleSpinBoxDAOFindFWHM, 1, 1, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.tab_4)
        self.label_7.setMinimumSize(QtCore.QSize(100, 0))
        self.label_7.setMaximumSize(QtCore.QSize(100, 16777215))
        self.label_7.setObjectName("label_7")
        self.gridLayout_8.addWidget(self.label_7, 2, 0, 1, 1)
        self.doubleSpinBoxDAOindThreshold = QtWidgets.QDoubleSpinBox(self.tab_4)
        self.doubleSpinBoxDAOindThreshold.setMinimum(1.0)
        self.doubleSpinBoxDAOindThreshold.setProperty("value", 5.0)
        self.doubleSpinBoxDAOindThreshold.setObjectName("doubleSpinBoxDAOindThreshold")
        self.gridLayout_8.addWidget(self.doubleSpinBoxDAOindThreshold, 2, 1, 1, 1)
        self.gridLayout_9.addLayout(self.gridLayout_8, 0, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_9.addItem(spacerItem4, 1, 0, 1, 1)
        self.tabWidget_2.addTab(self.tab_4, "")
        self.gridLayout_10.addWidget(self.tabWidget_2, 6, 0, 1, 2)
        spacerItem5 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_10.addItem(spacerItem5, 7, 1, 1, 1)
        self.comboBoxPhotometryMethods = QtWidgets.QComboBox(self.tab_2)
        self.comboBoxPhotometryMethods.setObjectName("comboBoxPhotometryMethods")
        self.comboBoxPhotometryMethods.addItem("")
        self.comboBoxPhotometryMethods.addItem("")
        self.comboBoxPhotometryMethods.addItem("")
        self.gridLayout_10.addWidget(self.comboBoxPhotometryMethods, 1, 0, 1, 2)
        self.comboBoxExposureInHeader = QtWidgets.QComboBox(self.tab_2)
        self.comboBoxExposureInHeader.setObjectName("comboBoxExposureInHeader")
        self.gridLayout_10.addWidget(self.comboBoxExposureInHeader, 3, 0, 1, 2)
        self.tabWidget.addTab(self.tab_2, "")
        self.gridLayout_4.addWidget(self.tabWidget, 0, 0, 1, 2)

        self.retranslateUi(FormPhotometry)
        self.tabWidget.setCurrentIndex(0)
        self.tabWidget_2.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(FormPhotometry)

    def retranslateUi(self, FormPhotometry):
        _translate = QtCore.QCoreApplication.translate
        FormPhotometry.setWindowTitle(_translate("FormPhotometry", "Photometry"))
        self.pushButtonGO.setText(_translate("FormPhotometry", ":go"))
        self.groupBox_2.setTitle(_translate("FormPhotometry", "Coordinates"))
        item = self.tableWidgetCoordinates.horizontalHeaderItem(0)
        item.setText(_translate("FormPhotometry", "X"))
        item = self.tableWidgetCoordinates.horizontalHeaderItem(1)
        item.setText(_translate("FormPhotometry", "Y"))
        self.groupBox.setTitle(_translate("FormPhotometry", "Image"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("FormPhotometry", "Photometry"))
        self.label.setText(_translate("FormPhotometry", "Kind"))
        self.label_2.setText(_translate("FormPhotometry", "Exposure"))
        self.groupBox_3.setTitle(_translate("FormPhotometry", "Apertures Radius"))
        self.pushButtonAddToRadii.setText(_translate("FormPhotometry", "Add"))
        self.groupBox_4.setTitle(_translate("FormPhotometry", "Header to Extract"))
        self.pushButtonAddToHeaderToExtract.setText(_translate("FormPhotometry", ">>"))
        self.pushButtonRemoveFromHeaderToExtract.setText(_translate("FormPhotometry", "<<"))
        self.label_3.setText(_translate("FormPhotometry", "Sigma"))
        self.label_4.setText(_translate("FormPhotometry", "Minimum Area"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_3), _translate("FormPhotometry", "Source Extract"))
        self.label_5.setText(_translate("FormPhotometry", "Sigma"))
        self.label_6.setText(_translate("FormPhotometry", "FWHM"))
        self.label_7.setText(_translate("FormPhotometry", "Threshold"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_4), _translate("FormPhotometry", "DAOFind"))
        self.comboBoxPhotometryMethods.setItemText(0, _translate("FormPhotometry", "Both"))
        self.comboBoxPhotometryMethods.setItemText(1, _translate("FormPhotometry", "SEP"))
        self.comboBoxPhotometryMethods.setItemText(2, _translate("FormPhotometry", "Photutils"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("FormPhotometry", "Settings"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormPhotometry = QtWidgets.QWidget()
    ui = Ui_FormPhotometry()
    ui.setupUi(FormPhotometry)
    FormPhotometry.show()
    sys.exit(app.exec_())
