# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ccdproc.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormCCDPROC(object):
    def setupUi(self, FormCCDPROC):
        FormCCDPROC.setObjectName("FormCCDPROC")
        FormCCDPROC.resize(567, 348)
        FormCCDPROC.setMinimumSize(QtCore.QSize(567, 348))
        self.gridLayout_5 = QtWidgets.QGridLayout(FormCCDPROC)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.tabWidget = QtWidgets.QTabWidget(FormCCDPROC)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.tab)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.groupBox_2 = QtWidgets.QGroupBox(self.tab)
        self.groupBox_2.setMinimumSize(QtCore.QSize(0, 94))
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_2.setObjectName("gridLayout_2")
        spacerItem = QtWidgets.QSpacerItem(407, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 1, 0, 1, 1)
        self.pushButtonDarkClear = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButtonDarkClear.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonDarkClear.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonDarkClear.setObjectName("pushButtonDarkClear")
        self.gridLayout_2.addWidget(self.pushButtonDarkClear, 1, 2, 1, 1)
        self.pushButtonDarkFile = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButtonDarkFile.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonDarkFile.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonDarkFile.setObjectName("pushButtonDarkFile")
        self.gridLayout_2.addWidget(self.pushButtonDarkFile, 1, 1, 1, 1)
        self.labelDarkFile = QtWidgets.QLabel(self.groupBox_2)
        self.labelDarkFile.setText("")
        self.labelDarkFile.setObjectName("labelDarkFile")
        self.gridLayout_2.addWidget(self.labelDarkFile, 0, 0, 1, 4)
        self.pushButtonDarkShow = QtWidgets.QPushButton(self.groupBox_2)
        self.pushButtonDarkShow.setEnabled(True)
        self.pushButtonDarkShow.setObjectName("pushButtonDarkShow")
        self.gridLayout_2.addWidget(self.pushButtonDarkShow, 1, 3, 1, 1)
        self.gridLayout_6.addWidget(self.groupBox_2, 1, 0, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.tab)
        self.groupBox.setMinimumSize(QtCore.QSize(0, 94))
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        spacerItem1 = QtWidgets.QSpacerItem(407, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 1, 0, 1, 1)
        self.pushButtonZeroShow = QtWidgets.QPushButton(self.groupBox)
        self.pushButtonZeroShow.setEnabled(True)
        self.pushButtonZeroShow.setObjectName("pushButtonZeroShow")
        self.gridLayout.addWidget(self.pushButtonZeroShow, 1, 3, 1, 1)
        self.pushButtonZeroFile = QtWidgets.QPushButton(self.groupBox)
        self.pushButtonZeroFile.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonZeroFile.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonZeroFile.setObjectName("pushButtonZeroFile")
        self.gridLayout.addWidget(self.pushButtonZeroFile, 1, 1, 1, 1)
        self.pushButtonZeroClear = QtWidgets.QPushButton(self.groupBox)
        self.pushButtonZeroClear.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonZeroClear.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonZeroClear.setObjectName("pushButtonZeroClear")
        self.gridLayout.addWidget(self.pushButtonZeroClear, 1, 2, 1, 1)
        self.labelZeroFile = QtWidgets.QLabel(self.groupBox)
        self.labelZeroFile.setText("")
        self.labelZeroFile.setObjectName("labelZeroFile")
        self.gridLayout.addWidget(self.labelZeroFile, 0, 0, 1, 4)
        self.gridLayout_6.addWidget(self.groupBox, 0, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.tab)
        self.groupBox_3.setMinimumSize(QtCore.QSize(0, 94))
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_3.setObjectName("gridLayout_3")
        spacerItem2 = QtWidgets.QSpacerItem(407, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem2, 1, 0, 1, 1)
        self.pushButtonFlatClear = QtWidgets.QPushButton(self.groupBox_3)
        self.pushButtonFlatClear.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonFlatClear.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonFlatClear.setObjectName("pushButtonFlatClear")
        self.gridLayout_3.addWidget(self.pushButtonFlatClear, 1, 2, 1, 1)
        self.pushButtonFlatFile = QtWidgets.QPushButton(self.groupBox_3)
        self.pushButtonFlatFile.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonFlatFile.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonFlatFile.setObjectName("pushButtonFlatFile")
        self.gridLayout_3.addWidget(self.pushButtonFlatFile, 1, 1, 1, 1)
        self.pushButtonFlatShow = QtWidgets.QPushButton(self.groupBox_3)
        self.pushButtonFlatShow.setEnabled(True)
        self.pushButtonFlatShow.setObjectName("pushButtonFlatShow")
        self.gridLayout_3.addWidget(self.pushButtonFlatShow, 1, 3, 1, 1)
        self.labelFlatFile = QtWidgets.QLabel(self.groupBox_3)
        self.labelFlatFile.setText("")
        self.labelFlatFile.setObjectName("labelFlatFile")
        self.gridLayout_3.addWidget(self.labelFlatFile, 0, 0, 1, 4)
        self.gridLayout_6.addWidget(self.groupBox_3, 2, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(17, 5, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_6.addItem(spacerItem3, 3, 0, 1, 1)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.tab_2)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.label = QtWidgets.QLabel(self.tab_2)
        self.label.setObjectName("label")
        self.gridLayout_4.addWidget(self.label, 0, 0, 1, 1)
        self.comboBoxExposureHeader = QtWidgets.QComboBox(self.tab_2)
        self.comboBoxExposureHeader.setObjectName("comboBoxExposureHeader")
        self.gridLayout_4.addWidget(self.comboBoxExposureHeader, 1, 0, 1, 1)
        self.checkBoxForce = QtWidgets.QCheckBox(self.tab_2)
        self.checkBoxForce.setObjectName("checkBoxForce")
        self.gridLayout_4.addWidget(self.checkBoxForce, 2, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(20, 160, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem4, 3, 0, 1, 1)
        self.tabWidget.addTab(self.tab_2, "")
        self.gridLayout_5.addWidget(self.tabWidget, 0, 0, 1, 2)
        spacerItem5 = QtWidgets.QSpacerItem(460, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem5, 1, 0, 1, 1)
        self.pushButtonGO = QtWidgets.QPushButton(FormCCDPROC)
        self.pushButtonGO.setEnabled(True)
        self.pushButtonGO.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setObjectName("pushButtonGO")
        self.gridLayout_5.addWidget(self.pushButtonGO, 1, 1, 1, 1)

        self.retranslateUi(FormCCDPROC)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(FormCCDPROC)

    def retranslateUi(self, FormCCDPROC):
        _translate = QtCore.QCoreApplication.translate
        FormCCDPROC.setWindowTitle(_translate("FormCCDPROC", "CCDPROC"))
        self.groupBox_2.setTitle(_translate("FormCCDPROC", "Master Dark"))
        self.pushButtonDarkClear.setText(_translate("FormCCDPROC", "Clear"))
        self.pushButtonDarkFile.setText(_translate("FormCCDPROC", "Open..."))
        self.pushButtonDarkShow.setText(_translate("FormCCDPROC", "Show"))
        self.groupBox.setTitle(_translate("FormCCDPROC", "Master Zero"))
        self.pushButtonZeroShow.setText(_translate("FormCCDPROC", "Show"))
        self.pushButtonZeroFile.setText(_translate("FormCCDPROC", "Open..."))
        self.pushButtonZeroClear.setText(_translate("FormCCDPROC", "Clear"))
        self.groupBox_3.setTitle(_translate("FormCCDPROC", "Master Flat"))
        self.pushButtonFlatClear.setText(_translate("FormCCDPROC", "Clear"))
        self.pushButtonFlatFile.setText(_translate("FormCCDPROC", "Open..."))
        self.pushButtonFlatShow.setText(_translate("FormCCDPROC", "Show"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("FormCCDPROC", "Calibration"))
        self.label.setText(_translate("FormCCDPROC", "Weight"))
        self.checkBoxForce.setText(_translate("FormCCDPROC", "Force"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("FormCCDPROC", "Settings"))
        self.pushButtonGO.setText(_translate("FormCCDPROC", ":go"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormCCDPROC = QtWidgets.QWidget()
    ui = Ui_FormCCDPROC()
    ui.setupUi(FormCCDPROC)
    FormCCDPROC.show()
    sys.exit(app.exec_())
