# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'cosmic_cleaner.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormCosmicCleaner(object):
    def setupUi(self, FormCosmicCleaner):
        FormCosmicCleaner.setObjectName("FormCosmicCleaner")
        FormCosmicCleaner.resize(349, 539)
        self.gridLayout_3 = QtWidgets.QGridLayout(FormCosmicCleaner)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.doubleSpinPsffwhm = QtWidgets.QDoubleSpinBox(FormCosmicCleaner)
        self.doubleSpinPsffwhm.setMinimum(-9999999999999.0)
        self.doubleSpinPsffwhm.setMaximum(9999999999999.0)
        self.doubleSpinPsffwhm.setProperty("value", 2.5)
        self.doubleSpinPsffwhm.setObjectName("doubleSpinPsffwhm")
        self.gridLayout_2.addWidget(self.doubleSpinPsffwhm, 11, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 3, 0, 1, 1)
        self.spinBoxNiter = QtWidgets.QSpinBox(FormCosmicCleaner)
        self.spinBoxNiter.setMaximum(999999999)
        self.spinBoxNiter.setProperty("value", 4)
        self.spinBoxNiter.setObjectName("spinBoxNiter")
        self.gridLayout_2.addWidget(self.spinBoxNiter, 6, 1, 1, 1)
        self.doubleSpinPsfbeta = QtWidgets.QDoubleSpinBox(FormCosmicCleaner)
        self.doubleSpinPsfbeta.setMinimum(-9999999999999.0)
        self.doubleSpinPsfbeta.setMaximum(9999999999999.0)
        self.doubleSpinPsfbeta.setProperty("value", 4.76)
        self.doubleSpinPsfbeta.setObjectName("doubleSpinPsfbeta")
        self.gridLayout_2.addWidget(self.doubleSpinPsfbeta, 13, 1, 1, 1)
        self.label_12 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_12.setObjectName("label_12")
        self.gridLayout_2.addWidget(self.label_12, 11, 0, 1, 1)
        self.comboBoxFsmode = QtWidgets.QComboBox(FormCosmicCleaner)
        self.comboBoxFsmode.setObjectName("comboBoxFsmode")
        self.comboBoxFsmode.addItem("")
        self.comboBoxFsmode.addItem("")
        self.gridLayout_2.addWidget(self.comboBoxFsmode, 9, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 2, 0, 1, 1)
        self.label = QtWidgets.QLabel(FormCosmicCleaner)
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 0, 0, 1, 1)
        self.label_8 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_8.setObjectName("label_8")
        self.gridLayout_2.addWidget(self.label_8, 6, 0, 1, 1)
        self.label_13 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_13.setObjectName("label_13")
        self.gridLayout_2.addWidget(self.label_13, 12, 0, 1, 1)
        self.checkBoxGain_apply = QtWidgets.QCheckBox(FormCosmicCleaner)
        self.checkBoxGain_apply.setChecked(True)
        self.checkBoxGain_apply.setObjectName("checkBoxGain_apply")
        self.gridLayout_2.addWidget(self.checkBoxGain_apply, 14, 0, 1, 2)
        self.label_11 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_11.setObjectName("label_11")
        self.gridLayout_2.addWidget(self.label_11, 10, 0, 1, 1)
        self.comboBoxCleantype = QtWidgets.QComboBox(FormCosmicCleaner)
        self.comboBoxCleantype.setObjectName("comboBoxCleantype")
        self.comboBoxCleantype.addItem("")
        self.comboBoxCleantype.addItem("")
        self.comboBoxCleantype.addItem("")
        self.comboBoxCleantype.addItem("")
        self.gridLayout_2.addWidget(self.comboBoxCleantype, 8, 1, 1, 1)
        self.label_9 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_9.setObjectName("label_9")
        self.gridLayout_2.addWidget(self.label_9, 8, 0, 1, 1)
        self.label_14 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_14.setObjectName("label_14")
        self.gridLayout_2.addWidget(self.label_14, 13, 0, 1, 1)
        self.doubleSpinObjlim = QtWidgets.QDoubleSpinBox(FormCosmicCleaner)
        self.doubleSpinObjlim.setMinimum(-9999999999999.0)
        self.doubleSpinObjlim.setMaximum(9999999999999.0)
        self.doubleSpinObjlim.setProperty("value", 5.0)
        self.doubleSpinObjlim.setObjectName("doubleSpinObjlim")
        self.gridLayout_2.addWidget(self.doubleSpinObjlim, 2, 1, 1, 1)
        self.doubleSpinSatlevel = QtWidgets.QDoubleSpinBox(FormCosmicCleaner)
        self.doubleSpinSatlevel.setMinimum(-9999999999999.0)
        self.doubleSpinSatlevel.setMaximum(9999999999999.0)
        self.doubleSpinSatlevel.setProperty("value", 65535.0)
        self.doubleSpinSatlevel.setObjectName("doubleSpinSatlevel")
        self.gridLayout_2.addWidget(self.doubleSpinSatlevel, 5, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_10.setObjectName("label_10")
        self.gridLayout_2.addWidget(self.label_10, 9, 0, 1, 1)
        self.doubleSpinReadnoise = QtWidgets.QDoubleSpinBox(FormCosmicCleaner)
        self.doubleSpinReadnoise.setMinimum(-9999999999999.0)
        self.doubleSpinReadnoise.setMaximum(9999999999999.0)
        self.doubleSpinReadnoise.setProperty("value", 6.5)
        self.doubleSpinReadnoise.setObjectName("doubleSpinReadnoise")
        self.gridLayout_2.addWidget(self.doubleSpinReadnoise, 4, 1, 1, 1)
        self.label_5 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 4, 0, 1, 1)
        self.doubleSpinGain = QtWidgets.QDoubleSpinBox(FormCosmicCleaner)
        self.doubleSpinGain.setMinimum(-9999999999999.0)
        self.doubleSpinGain.setMaximum(9999999999999.0)
        self.doubleSpinGain.setProperty("value", 1.0)
        self.doubleSpinGain.setObjectName("doubleSpinGain")
        self.gridLayout_2.addWidget(self.doubleSpinGain, 3, 1, 1, 1)
        self.doubleSpinSigclip = QtWidgets.QDoubleSpinBox(FormCosmicCleaner)
        self.doubleSpinSigclip.setMinimum(-99999999999999.0)
        self.doubleSpinSigclip.setMaximum(99999999999999.0)
        self.doubleSpinSigclip.setProperty("value", 4.5)
        self.doubleSpinSigclip.setObjectName("doubleSpinSigclip")
        self.gridLayout_2.addWidget(self.doubleSpinSigclip, 0, 1, 1, 1)
        self.spinBoxPsfsize = QtWidgets.QSpinBox(FormCosmicCleaner)
        self.spinBoxPsfsize.setMaximum(999999999)
        self.spinBoxPsfsize.setProperty("value", 7)
        self.spinBoxPsfsize.setObjectName("spinBoxPsfsize")
        self.gridLayout_2.addWidget(self.spinBoxPsfsize, 12, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 5, 0, 1, 1)
        self.checkBoxSepmed = QtWidgets.QCheckBox(FormCosmicCleaner)
        self.checkBoxSepmed.setChecked(True)
        self.checkBoxSepmed.setObjectName("checkBoxSepmed")
        self.gridLayout_2.addWidget(self.checkBoxSepmed, 7, 0, 1, 2)
        self.label_2 = QtWidgets.QLabel(FormCosmicCleaner)
        self.label_2.setObjectName("label_2")
        self.gridLayout_2.addWidget(self.label_2, 1, 0, 1, 1)
        self.doubleSpinSigfrac = QtWidgets.QDoubleSpinBox(FormCosmicCleaner)
        self.doubleSpinSigfrac.setMinimum(-99999999999.0)
        self.doubleSpinSigfrac.setMaximum(99999999999.0)
        self.doubleSpinSigfrac.setProperty("value", 0.3)
        self.doubleSpinSigfrac.setObjectName("doubleSpinSigfrac")
        self.gridLayout_2.addWidget(self.doubleSpinSigfrac, 1, 1, 1, 1)
        self.comboBoxPsfmodel = QtWidgets.QComboBox(FormCosmicCleaner)
        self.comboBoxPsfmodel.setObjectName("comboBoxPsfmodel")
        self.comboBoxPsfmodel.addItem("")
        self.comboBoxPsfmodel.addItem("")
        self.comboBoxPsfmodel.addItem("")
        self.comboBoxPsfmodel.addItem("")
        self.gridLayout_2.addWidget(self.comboBoxPsfmodel, 10, 1, 1, 1)
        self.gridLayout_3.addLayout(self.gridLayout_2, 0, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 2, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem, 1, 0, 1, 1)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        spacerItem1 = QtWidgets.QSpacerItem(333, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 0, 0, 1, 1)
        self.pushButtonGO = QtWidgets.QPushButton(FormCosmicCleaner)
        self.pushButtonGO.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setObjectName("pushButtonGO")
        self.gridLayout.addWidget(self.pushButtonGO, 0, 1, 1, 1)
        self.gridLayout_3.addLayout(self.gridLayout, 2, 0, 1, 1)

        self.retranslateUi(FormCosmicCleaner)
        QtCore.QMetaObject.connectSlotsByName(FormCosmicCleaner)

    def retranslateUi(self, FormCosmicCleaner):
        _translate = QtCore.QCoreApplication.translate
        FormCosmicCleaner.setWindowTitle(_translate("FormCosmicCleaner", "Cosmic Cleaner"))
        self.label_4.setText(_translate("FormCosmicCleaner", "gain"))
        self.label_12.setText(_translate("FormCosmicCleaner", "psffwhm"))
        self.comboBoxFsmode.setItemText(0, _translate("FormCosmicCleaner", "Median"))
        self.comboBoxFsmode.setItemText(1, _translate("FormCosmicCleaner", "Convolve"))
        self.label_3.setText(_translate("FormCosmicCleaner", "objlim"))
        self.label.setText(_translate("FormCosmicCleaner", "sigclip"))
        self.label_8.setText(_translate("FormCosmicCleaner", "niter"))
        self.label_13.setText(_translate("FormCosmicCleaner", "psfsize"))
        self.checkBoxGain_apply.setText(_translate("FormCosmicCleaner", "gain_apply"))
        self.label_11.setText(_translate("FormCosmicCleaner", "psfmodel"))
        self.comboBoxCleantype.setItemText(0, _translate("FormCosmicCleaner", "Median"))
        self.comboBoxCleantype.setItemText(1, _translate("FormCosmicCleaner", "MedMask"))
        self.comboBoxCleantype.setItemText(2, _translate("FormCosmicCleaner", "MeanMask"))
        self.comboBoxCleantype.setItemText(3, _translate("FormCosmicCleaner", "idw"))
        self.label_9.setText(_translate("FormCosmicCleaner", "cleantype"))
        self.label_14.setText(_translate("FormCosmicCleaner", "psfbeta"))
        self.label_10.setText(_translate("FormCosmicCleaner", "fsmode"))
        self.label_5.setText(_translate("FormCosmicCleaner", "readnoise"))
        self.label_6.setText(_translate("FormCosmicCleaner", "satlevel"))
        self.checkBoxSepmed.setText(_translate("FormCosmicCleaner", "sepmed"))
        self.label_2.setText(_translate("FormCosmicCleaner", "sigfrac"))
        self.comboBoxPsfmodel.setItemText(0, _translate("FormCosmicCleaner", "Gauss"))
        self.comboBoxPsfmodel.setItemText(1, _translate("FormCosmicCleaner", "Moffat"))
        self.comboBoxPsfmodel.setItemText(2, _translate("FormCosmicCleaner", "GaussX"))
        self.comboBoxPsfmodel.setItemText(3, _translate("FormCosmicCleaner", "GaussY"))
        self.pushButtonGO.setText(_translate("FormCosmicCleaner", ":go"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormCosmicCleaner = QtWidgets.QWidget()
    ui = Ui_FormCosmicCleaner()
    ui.setupUi(FormCosmicCleaner)
    FormCosmicCleaner.show()
    sys.exit(app.exec_())
