# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'log.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormLog(object):
    def setupUi(self, FormLog):
        FormLog.setObjectName("FormLog")
        FormLog.resize(763, 671)
        self.gridLayout_2 = QtWidgets.QGridLayout(FormLog)
        self.gridLayout_2.setObjectName("gridLayout_2")
        spacerItem = QtWidgets.QSpacerItem(570, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 1, 0, 1, 1)
        self.pushButtonRefresh = QtWidgets.QPushButton(FormLog)
        self.pushButtonRefresh.setObjectName("pushButtonRefresh")
        self.gridLayout_2.addWidget(self.pushButtonRefresh, 1, 2, 1, 1)
        self.pushButtonSave = QtWidgets.QPushButton(FormLog)
        self.pushButtonSave.setObjectName("pushButtonSave")
        self.gridLayout_2.addWidget(self.pushButtonSave, 1, 3, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(FormLog)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.listWidget = QtWidgets.QListWidget(self.groupBox)
        self.listWidget.setObjectName("listWidget")
        self.gridLayout.addWidget(self.listWidget, 0, 0, 1, 1)
        self.gridLayout_2.addWidget(self.groupBox, 0, 0, 1, 4)
        self.pushButtonClear = QtWidgets.QPushButton(FormLog)
        self.pushButtonClear.setObjectName("pushButtonClear")
        self.gridLayout_2.addWidget(self.pushButtonClear, 1, 1, 1, 1)

        self.retranslateUi(FormLog)
        QtCore.QMetaObject.connectSlotsByName(FormLog)

    def retranslateUi(self, FormLog):
        _translate = QtCore.QCoreApplication.translate
        FormLog.setWindowTitle(_translate("FormLog", "Log"))
        self.pushButtonRefresh.setText(_translate("FormLog", "Refresh"))
        self.pushButtonSave.setText(_translate("FormLog", "Save"))
        self.groupBox.setTitle(_translate("FormLog", "Log"))
        self.pushButtonClear.setText(_translate("FormLog", "Clear"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormLog = QtWidgets.QWidget()
    ui = Ui_FormLog()
    ui.setupUi(FormLog)
    FormLog.show()
    sys.exit(app.exec_())
