# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'header_calculator.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormHeaderCalculator(object):
    def setupUi(self, FormHeaderCalculator):
        FormHeaderCalculator.setObjectName("FormHeaderCalculator")
        FormHeaderCalculator.resize(362, 268)
        self.gridLayout_3 = QtWidgets.QGridLayout(FormHeaderCalculator)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label = QtWidgets.QLabel(FormHeaderCalculator)
        self.label.setMinimumSize(QtCore.QSize(95, 18))
        self.label.setMaximumSize(QtCore.QSize(95, 18))
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 0, 0, 1, 1)
        self.comboBoxTimeInHeader = QtWidgets.QComboBox(FormHeaderCalculator)
        self.comboBoxTimeInHeader.setObjectName("comboBoxTimeInHeader")
        self.gridLayout_3.addWidget(self.comboBoxTimeInHeader, 0, 1, 1, 2)
        self.groupBoxTime = QtWidgets.QGroupBox(FormHeaderCalculator)
        self.groupBoxTime.setCheckable(True)
        self.groupBoxTime.setChecked(False)
        self.groupBoxTime.setObjectName("groupBoxTime")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBoxTime)
        self.gridLayout.setObjectName("gridLayout")
        self.label_2 = QtWidgets.QLabel(self.groupBoxTime)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 0, 0, 1, 1)
        self.doubleSpinBoxTimeAmount = QtWidgets.QDoubleSpinBox(self.groupBoxTime)
        self.doubleSpinBoxTimeAmount.setMinimum(-1e+16)
        self.doubleSpinBoxTimeAmount.setProperty("value", 0.0)
        self.doubleSpinBoxTimeAmount.setObjectName("doubleSpinBoxTimeAmount")
        self.gridLayout.addWidget(self.doubleSpinBoxTimeAmount, 0, 1, 1, 1)
        self.comboBoxTimeType = QtWidgets.QComboBox(self.groupBoxTime)
        self.comboBoxTimeType.setObjectName("comboBoxTimeType")
        self.comboBoxTimeType.addItem("")
        self.comboBoxTimeType.addItem("")
        self.comboBoxTimeType.addItem("")
        self.comboBoxTimeType.addItem("")
        self.comboBoxTimeType.addItem("")
        self.comboBoxTimeType.addItem("")
        self.gridLayout.addWidget(self.comboBoxTimeType, 0, 2, 1, 1)
        self.gridLayout_3.addWidget(self.groupBoxTime, 1, 0, 1, 3)
        self.groupBoxJDAirmass = QtWidgets.QGroupBox(FormHeaderCalculator)
        self.groupBoxJDAirmass.setCheckable(True)
        self.groupBoxJDAirmass.setChecked(False)
        self.groupBoxJDAirmass.setObjectName("groupBoxJDAirmass")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBoxJDAirmass)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_6 = QtWidgets.QLabel(self.groupBoxJDAirmass)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 1, 0, 1, 1)
        self.comboBoxObservatoryInHeader = QtWidgets.QComboBox(self.groupBoxJDAirmass)
        self.comboBoxObservatoryInHeader.setObjectName("comboBoxObservatoryInHeader")
        self.gridLayout_2.addWidget(self.comboBoxObservatoryInHeader, 0, 1, 1, 1)
        self.comboBoxObjectInHeader = QtWidgets.QComboBox(self.groupBoxJDAirmass)
        self.comboBoxObjectInHeader.setObjectName("comboBoxObjectInHeader")
        self.gridLayout_2.addWidget(self.comboBoxObjectInHeader, 1, 1, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBoxJDAirmass)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 0, 0, 1, 1)
        self.gridLayout_3.addWidget(self.groupBoxJDAirmass, 2, 0, 1, 3)
        spacerItem = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem, 3, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(255, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem1, 4, 0, 1, 2)
        self.pushButtonGO = QtWidgets.QPushButton(FormHeaderCalculator)
        self.pushButtonGO.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setObjectName("pushButtonGO")
        self.gridLayout_3.addWidget(self.pushButtonGO, 4, 2, 1, 1)

        self.retranslateUi(FormHeaderCalculator)
        self.comboBoxTimeType.setCurrentIndex(5)
        QtCore.QMetaObject.connectSlotsByName(FormHeaderCalculator)

    def retranslateUi(self, FormHeaderCalculator):
        _translate = QtCore.QCoreApplication.translate
        FormHeaderCalculator.setWindowTitle(_translate("FormHeaderCalculator", "Header Calculator"))
        self.label.setText(_translate("FormHeaderCalculator", "Time in Header"))
        self.groupBoxTime.setTitle(_translate("FormHeaderCalculator", "Time"))
        self.label_2.setText(_translate("FormHeaderCalculator", "Amount"))
        self.comboBoxTimeType.setItemText(0, _translate("FormHeaderCalculator", "Year"))
        self.comboBoxTimeType.setItemText(1, _translate("FormHeaderCalculator", "Month"))
        self.comboBoxTimeType.setItemText(2, _translate("FormHeaderCalculator", "Day"))
        self.comboBoxTimeType.setItemText(3, _translate("FormHeaderCalculator", "Hour"))
        self.comboBoxTimeType.setItemText(4, _translate("FormHeaderCalculator", "Minute"))
        self.comboBoxTimeType.setItemText(5, _translate("FormHeaderCalculator", "Second"))
        self.groupBoxJDAirmass.setTitle(_translate("FormHeaderCalculator", "?JD / Airmass"))
        self.label_6.setText(_translate("FormHeaderCalculator", "Object in Header"))
        self.label_5.setText(_translate("FormHeaderCalculator", "Observatory in Header"))
        self.pushButtonGO.setText(_translate("FormHeaderCalculator", ":go"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormHeaderCalculator = QtWidgets.QWidget()
    ui = Ui_FormHeaderCalculator()
    ui.setupUi(FormHeaderCalculator)
    FormHeaderCalculator.show()
    sys.exit(app.exec_())
