# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'header.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormHeader(object):
    def setupUi(self, FormHeader):
        FormHeader.setObjectName("FormHeader")
        FormHeader.resize(920, 732)
        self.gridLayout_3 = QtWidgets.QGridLayout(FormHeader)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.groupBox = QtWidgets.QGroupBox(FormHeader)
        self.groupBox.setMinimumSize(QtCore.QSize(280, 0))
        self.groupBox.setMaximumSize(QtCore.QSize(280, 16777215))
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.listWidgetFiles = QtWidgets.QListWidget(self.groupBox)
        self.listWidgetFiles.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.listWidgetFiles.setObjectName("listWidgetFiles")
        self.gridLayout.addWidget(self.listWidgetFiles, 0, 0, 1, 1)
        self.gridLayout_3.addWidget(self.groupBox, 0, 0, 1, 1)
        self.groupBox_2 = QtWidgets.QGroupBox(FormHeader)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.tableWidgetHeaders = QtWidgets.QTableWidget(self.groupBox_2)
        self.tableWidgetHeaders.setObjectName("tableWidgetHeaders")
        self.tableWidgetHeaders.setColumnCount(3)
        self.tableWidgetHeaders.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetHeaders.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetHeaders.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetHeaders.setHorizontalHeaderItem(2, item)
        self.gridLayout_2.addWidget(self.tableWidgetHeaders, 0, 0, 1, 1)
        self.gridLayout_3.addWidget(self.groupBox_2, 0, 1, 1, 1)

        self.retranslateUi(FormHeader)
        QtCore.QMetaObject.connectSlotsByName(FormHeader)

    def retranslateUi(self, FormHeader):
        _translate = QtCore.QCoreApplication.translate
        FormHeader.setWindowTitle(_translate("FormHeader", "Header"))
        self.groupBox.setTitle(_translate("FormHeader", "File"))
        self.groupBox_2.setTitle(_translate("FormHeader", "Header"))
        item = self.tableWidgetHeaders.horizontalHeaderItem(0)
        item.setText(_translate("FormHeader", "Key"))
        item = self.tableWidgetHeaders.horizontalHeaderItem(1)
        item.setText(_translate("FormHeader", "Value"))
        item = self.tableWidgetHeaders.horizontalHeaderItem(2)
        item.setText(_translate("FormHeader", "Comment"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormHeader = QtWidgets.QWidget()
    ui = Ui_FormHeader()
    ui.setupUi(FormHeader)
    FormHeader.show()
    sys.exit(app.exec_())
