# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'wcs.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormWCS(object):
    def setupUi(self, FormWCS):
        FormWCS.setObjectName("FormWCS")
        FormWCS.resize(668, 849)
        self.gridLayout = QtWidgets.QGridLayout(FormWCS)
        self.gridLayout.setObjectName("gridLayout")
        self.groupBox_3 = QtWidgets.QGroupBox(FormWCS)
        self.groupBox_3.setMinimumSize(QtCore.QSize(650, 175))
        self.groupBox_3.setMaximumSize(QtCore.QSize(16777215, 175))
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_2 = QtWidgets.QLabel(self.groupBox_3)
        self.label_2.setObjectName("label_2")
        self.gridLayout_2.addWidget(self.label_2, 1, 0, 1, 1)
        self.labelY = QtWidgets.QLabel(self.groupBox_3)
        self.labelY.setText("")
        self.labelY.setObjectName("labelY")
        self.gridLayout_2.addWidget(self.labelY, 4, 2, 1, 1)
        self.labelX = QtWidgets.QLabel(self.groupBox_3)
        self.labelX.setText("")
        self.labelX.setObjectName("labelX")
        self.gridLayout_2.addWidget(self.labelX, 4, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_3)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 2, 0, 1, 1)
        self.labelValue = QtWidgets.QLabel(self.groupBox_3)
        self.labelValue.setText("")
        self.labelValue.setObjectName("labelValue")
        self.gridLayout_2.addWidget(self.labelValue, 2, 1, 1, 2)
        self.labelDec = QtWidgets.QLabel(self.groupBox_3)
        self.labelDec.setText("")
        self.labelDec.setObjectName("labelDec")
        self.gridLayout_2.addWidget(self.labelDec, 3, 2, 1, 1)
        self.labelRa = QtWidgets.QLabel(self.groupBox_3)
        self.labelRa.setText("")
        self.labelRa.setObjectName("labelRa")
        self.gridLayout_2.addWidget(self.labelRa, 3, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_3)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 3, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_3)
        self.label.setObjectName("label")
        self.gridLayout_2.addWidget(self.label, 0, 0, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_3)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 4, 0, 1, 1)
        self.labelObject = QtWidgets.QLabel(self.groupBox_3)
        self.labelObject.setText("")
        self.labelObject.setObjectName("labelObject")
        self.gridLayout_2.addWidget(self.labelObject, 1, 1, 1, 2)
        self.comboBoxFile = QtWidgets.QComboBox(self.groupBox_3)
        self.comboBoxFile.setObjectName("comboBoxFile")
        self.gridLayout_2.addWidget(self.comboBoxFile, 0, 1, 1, 2)
        self.gridLayout_3.addLayout(self.gridLayout_2, 0, 0, 1, 1)
        self.gridLayout.addWidget(self.groupBox_3, 0, 0, 1, 2)
        self.groupBox = QtWidgets.QGroupBox(FormWCS)
        self.groupBox.setMinimumSize(QtCore.QSize(0, 550))
        self.groupBox.setObjectName("groupBox")
        self.gridLayout.addWidget(self.groupBox, 1, 0, 1, 2)
        spacerItem = QtWidgets.QSpacerItem(561, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 2, 0, 1, 1)
        self.pushButtonGO = QtWidgets.QPushButton(FormWCS)
        self.pushButtonGO.setObjectName("pushButtonGO")
        self.gridLayout.addWidget(self.pushButtonGO, 2, 1, 1, 1)

        self.retranslateUi(FormWCS)
        QtCore.QMetaObject.connectSlotsByName(FormWCS)

    def retranslateUi(self, FormWCS):
        _translate = QtCore.QCoreApplication.translate
        FormWCS.setWindowTitle(_translate("FormWCS", "WCS"))
        self.groupBox_3.setTitle(_translate("FormWCS", "Information"))
        self.label_2.setText(_translate("FormWCS", "Object"))
        self.label_3.setText(_translate("FormWCS", "Value"))
        self.label_4.setText(_translate("FormWCS", "WCS"))
        self.label.setText(_translate("FormWCS", "File"))
        self.label_5.setText(_translate("FormWCS", "Physical"))
        self.groupBox.setTitle(_translate("FormWCS", "Image"))
        self.pushButtonGO.setText(_translate("FormWCS", ":go"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormWCS = QtWidgets.QWidget()
    ui = Ui_FormWCS()
    ui.setupUi(FormWCS)
    FormWCS.show()
    sys.exit(app.exec_())
