# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'combine.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormCombine(object):
    def setupUi(self, FormCombine):
        FormCombine.setObjectName("FormCombine")
        FormCombine.resize(325, 295)
        self.gridLayout = QtWidgets.QGridLayout(FormCombine)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(FormCombine)
        self.label.setMinimumSize(QtCore.QSize(108, 26))
        self.label.setMaximumSize(QtCore.QSize(108, 26))
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.comboBoxMethod = QtWidgets.QComboBox(FormCombine)
        self.comboBoxMethod.setObjectName("comboBoxMethod")
        self.comboBoxMethod.addItem("")
        self.comboBoxMethod.addItem("")
        self.comboBoxMethod.addItem("")
        self.comboBoxMethod.addItem("")
        self.gridLayout.addWidget(self.comboBoxMethod, 0, 1, 1, 2)
        self.label_2 = QtWidgets.QLabel(FormCombine)
        self.label_2.setMinimumSize(QtCore.QSize(108, 26))
        self.label_2.setMaximumSize(QtCore.QSize(108, 26))
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
        self.comboBoxClipping = QtWidgets.QComboBox(FormCombine)
        self.comboBoxClipping.setObjectName("comboBoxClipping")
        self.comboBoxClipping.addItem("")
        self.comboBoxClipping.addItem("")
        self.comboBoxClipping.addItem("")
        self.gridLayout.addWidget(self.comboBoxClipping, 1, 1, 1, 2)
        self.label_3 = QtWidgets.QLabel(FormCombine)
        self.label_3.setMinimumSize(QtCore.QSize(108, 26))
        self.label_3.setMaximumSize(QtCore.QSize(108, 26))
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
        self.comboBoxWeight = QtWidgets.QComboBox(FormCombine)
        self.comboBoxWeight.setObjectName("comboBoxWeight")
        self.comboBoxWeight.addItem("")
        self.comboBoxWeight.addItem("")
        self.gridLayout.addWidget(self.comboBoxWeight, 2, 1, 1, 2)
        self.tableWidgetWeights = QtWidgets.QTableWidget(FormCombine)
        self.tableWidgetWeights.setObjectName("tableWidgetWeights")
        self.tableWidgetWeights.setColumnCount(2)
        self.tableWidgetWeights.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetWeights.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetWeights.setHorizontalHeaderItem(1, item)
        self.gridLayout.addWidget(self.tableWidgetWeights, 3, 0, 1, 3)
        spacerItem = QtWidgets.QSpacerItem(265, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 4, 0, 1, 2)
        self.pushButtonGo = QtWidgets.QPushButton(FormCombine)
        self.pushButtonGo.setMinimumSize(QtCore.QSize(80, 26))
        self.pushButtonGo.setMaximumSize(QtCore.QSize(80, 26))
        self.pushButtonGo.setObjectName("pushButtonGo")
        self.gridLayout.addWidget(self.pushButtonGo, 4, 2, 1, 1)

        self.retranslateUi(FormCombine)
        self.comboBoxWeight.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(FormCombine)

    def retranslateUi(self, FormCombine):
        _translate = QtCore.QCoreApplication.translate
        FormCombine.setWindowTitle(_translate("FormCombine", "Combine"))
        self.label.setText(_translate("FormCombine", "method"))
        self.comboBoxMethod.setItemText(0, _translate("FormCombine", "Average"))
        self.comboBoxMethod.setItemText(1, _translate("FormCombine", "Mean"))
        self.comboBoxMethod.setItemText(2, _translate("FormCombine", "Median"))
        self.comboBoxMethod.setItemText(3, _translate("FormCombine", "Sum"))
        self.label_2.setText(_translate("FormCombine", "clipping"))
        self.comboBoxClipping.setItemText(0, _translate("FormCombine", "None"))
        self.comboBoxClipping.setItemText(1, _translate("FormCombine", "Sigma"))
        self.comboBoxClipping.setItemText(2, _translate("FormCombine", "Minmax"))
        self.label_3.setText(_translate("FormCombine", "Weight"))
        self.comboBoxWeight.setItemText(0, _translate("FormCombine", "None"))
        self.comboBoxWeight.setItemText(1, _translate("FormCombine", "Custom"))
        item = self.tableWidgetWeights.horizontalHeaderItem(0)
        item.setText(_translate("FormCombine", "File"))
        item = self.tableWidgetWeights.horizontalHeaderItem(1)
        item.setText(_translate("FormCombine", "Weight"))
        self.pushButtonGo.setText(_translate("FormCombine", ":go"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormCombine = QtWidgets.QWidget()
    ui = Ui_FormCombine()
    ui.setupUi(FormCombine)
    FormCombine.show()
    sys.exit(app.exec_())
