# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'hedit.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormHedit(object):
    def setupUi(self, FormHedit):
        FormHedit.setObjectName("FormHedit")
        FormHedit.resize(573, 595)
        self.gridLayout_5 = QtWidgets.QGridLayout(FormHedit)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.groupBox = QtWidgets.QGroupBox(FormHedit)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.tableWidgetHeaders = QtWidgets.QTableWidget(self.groupBox)
        self.tableWidgetHeaders.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tableWidgetHeaders.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tableWidgetHeaders.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableWidgetHeaders.setObjectName("tableWidgetHeaders")
        self.tableWidgetHeaders.setColumnCount(3)
        self.tableWidgetHeaders.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetHeaders.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetHeaders.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetHeaders.setHorizontalHeaderItem(2, item)
        self.gridLayout_2.addWidget(self.tableWidgetHeaders, 0, 0, 1, 1)
        self.gridLayout_5.addWidget(self.groupBox, 0, 1, 1, 1)
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label = QtWidgets.QLabel(FormHedit)
        self.label.setMaximumSize(QtCore.QSize(16777215, 18))
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 0, 0, 1, 1)
        self.lineEditKey = QtWidgets.QLineEdit(FormHedit)
        self.lineEditKey.setMaximumSize(QtCore.QSize(16777215, 26))
        self.lineEditKey.setMaxLength(8)
        self.lineEditKey.setObjectName("lineEditKey")
        self.gridLayout_3.addWidget(self.lineEditKey, 0, 1, 1, 1)
        self.checkBoxUseFromValue = QtWidgets.QCheckBox(FormHedit)
        self.checkBoxUseFromValue.setMaximumSize(QtCore.QSize(16777215, 24))
        self.checkBoxUseFromValue.setObjectName("checkBoxUseFromValue")
        self.gridLayout_3.addWidget(self.checkBoxUseFromValue, 0, 2, 1, 1)
        self.label_2 = QtWidgets.QLabel(FormHedit)
        self.label_2.setMaximumSize(QtCore.QSize(16777215, 18))
        self.label_2.setObjectName("label_2")
        self.gridLayout_3.addWidget(self.label_2, 1, 0, 1, 1)
        self.lineEditValue = QtWidgets.QLineEdit(FormHedit)
        self.lineEditValue.setMaximumSize(QtCore.QSize(16777215, 26))
        self.lineEditValue.setMaxLength(68)
        self.lineEditValue.setObjectName("lineEditValue")
        self.gridLayout_3.addWidget(self.lineEditValue, 1, 1, 1, 1)
        self.comboBoxValue = QtWidgets.QComboBox(FormHedit)
        self.comboBoxValue.setEnabled(False)
        self.comboBoxValue.setMaximumSize(QtCore.QSize(16777215, 26))
        self.comboBoxValue.setObjectName("comboBoxValue")
        self.gridLayout_3.addWidget(self.comboBoxValue, 1, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(FormHedit)
        self.label_3.setObjectName("label_3")
        self.gridLayout_3.addWidget(self.label_3, 2, 0, 1, 1)
        self.lineEditComment = QtWidgets.QLineEdit(FormHedit)
        self.lineEditComment.setMaxLength(68)
        self.lineEditComment.setObjectName("lineEditComment")
        self.gridLayout_3.addWidget(self.lineEditComment, 2, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem, 2, 2, 1, 1)
        self.gridLayout_5.addLayout(self.gridLayout_3, 1, 0, 1, 2)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        spacerItem1 = QtWidgets.QSpacerItem(308, 22, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 0, 0, 1, 1)
        self.pushButtonDelete = QtWidgets.QPushButton(FormHedit)
        self.pushButtonDelete.setMinimumSize(QtCore.QSize(100, 25))
        self.pushButtonDelete.setMaximumSize(QtCore.QSize(100, 25))
        self.pushButtonDelete.setObjectName("pushButtonDelete")
        self.gridLayout.addWidget(self.pushButtonDelete, 0, 1, 1, 1)
        self.pushButtonSaveUpdate = QtWidgets.QPushButton(FormHedit)
        self.pushButtonSaveUpdate.setMinimumSize(QtCore.QSize(100, 25))
        self.pushButtonSaveUpdate.setMaximumSize(QtCore.QSize(100, 25))
        self.pushButtonSaveUpdate.setObjectName("pushButtonSaveUpdate")
        self.gridLayout.addWidget(self.pushButtonSaveUpdate, 0, 2, 1, 1)
        self.gridLayout_5.addLayout(self.gridLayout, 2, 0, 1, 2)

        self.retranslateUi(FormHedit)
        QtCore.QMetaObject.connectSlotsByName(FormHedit)

    def retranslateUi(self, FormHedit):
        _translate = QtCore.QCoreApplication.translate
        FormHedit.setWindowTitle(_translate("FormHedit", "Headit"))
        self.groupBox.setTitle(_translate("FormHedit", "Header"))
        item = self.tableWidgetHeaders.horizontalHeaderItem(0)
        item.setText(_translate("FormHedit", "Card"))
        item = self.tableWidgetHeaders.horizontalHeaderItem(1)
        item.setText(_translate("FormHedit", "Value"))
        item = self.tableWidgetHeaders.horizontalHeaderItem(2)
        item.setText(_translate("FormHedit", "Comment"))
        self.label.setText(_translate("FormHedit", "Key"))
        self.checkBoxUseFromValue.setText(_translate("FormHedit", "Use value from existing field"))
        self.label_2.setText(_translate("FormHedit", "Value"))
        self.label_3.setText(_translate("FormHedit", "Comment"))
        self.pushButtonDelete.setText(_translate("FormHedit", "Delete"))
        self.pushButtonSaveUpdate.setText(_translate("FormHedit", "Save/Update"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormHedit = QtWidgets.QWidget()
    ui = Ui_FormHedit()
    ui.setupUi(FormHedit)
    FormHedit.show()
    sys.exit(app.exec_())
