# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'crop.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormCrop(object):
    def setupUi(self, FormCrop):
        FormCrop.setObjectName("FormCrop")
        FormCrop.resize(572, 644)
        self.gridLayout_2 = QtWidgets.QGridLayout(FormCrop)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.groupBox = QtWidgets.QGroupBox(FormCrop)
        self.groupBox.setMinimumSize(QtCore.QSize(554, 484))
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_2.addWidget(self.groupBox, 0, 0, 1, 2)
        self.groupBox_2 = QtWidgets.QGroupBox(FormCrop)
        self.groupBox_2.setMinimumSize(QtCore.QSize(0, 105))
        self.groupBox_2.setMaximumSize(QtCore.QSize(16777215, 105))
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(self.groupBox_2)
        self.label.setMinimumSize(QtCore.QSize(0, 18))
        self.label.setMaximumSize(QtCore.QSize(16, 18))
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.spinBoxXAmount = QtWidgets.QSpinBox(self.groupBox_2)
        self.spinBoxXAmount.setMinimumSize(QtCore.QSize(0, 25))
        self.spinBoxXAmount.setMaximumSize(QtCore.QSize(16777215, 25))
        self.spinBoxXAmount.setMaximum(999999999)
        self.spinBoxXAmount.setObjectName("spinBoxXAmount")
        self.gridLayout.addWidget(self.spinBoxXAmount, 0, 1, 1, 1)
        self.line = QtWidgets.QFrame(self.groupBox_2)
        self.line.setMinimumSize(QtCore.QSize(0, 27))
        self.line.setMaximumSize(QtCore.QSize(16777215, 27))
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridLayout.addWidget(self.line, 0, 2, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBox_2)
        self.label_2.setMinimumSize(QtCore.QSize(0, 25))
        self.label_2.setMaximumSize(QtCore.QSize(16, 25))
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 0, 3, 1, 1)
        self.spinBoxYAmount = QtWidgets.QSpinBox(self.groupBox_2)
        self.spinBoxYAmount.setMinimumSize(QtCore.QSize(0, 25))
        self.spinBoxYAmount.setMaximumSize(QtCore.QSize(16777215, 25))
        self.spinBoxYAmount.setMaximum(999999999)
        self.spinBoxYAmount.setObjectName("spinBoxYAmount")
        self.gridLayout.addWidget(self.spinBoxYAmount, 0, 4, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_2)
        self.label_3.setMinimumSize(QtCore.QSize(0, 18))
        self.label_3.setMaximumSize(QtCore.QSize(16, 18))
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)
        self.spinBoxWAmount = QtWidgets.QSpinBox(self.groupBox_2)
        self.spinBoxWAmount.setMinimumSize(QtCore.QSize(0, 25))
        self.spinBoxWAmount.setMaximumSize(QtCore.QSize(16777215, 25))
        self.spinBoxWAmount.setMinimum(1)
        self.spinBoxWAmount.setMaximum(999999999)
        self.spinBoxWAmount.setObjectName("spinBoxWAmount")
        self.gridLayout.addWidget(self.spinBoxWAmount, 1, 1, 1, 1)
        self.line_2 = QtWidgets.QFrame(self.groupBox_2)
        self.line_2.setMinimumSize(QtCore.QSize(0, 27))
        self.line_2.setMaximumSize(QtCore.QSize(16777215, 27))
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridLayout.addWidget(self.line_2, 1, 2, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_2)
        self.label_4.setMinimumSize(QtCore.QSize(0, 25))
        self.label_4.setMaximumSize(QtCore.QSize(16, 25))
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 1, 3, 1, 1)
        self.spinBoxHAmount = QtWidgets.QSpinBox(self.groupBox_2)
        self.spinBoxHAmount.setMinimumSize(QtCore.QSize(0, 25))
        self.spinBoxHAmount.setMaximumSize(QtCore.QSize(16777215, 25))
        self.spinBoxHAmount.setMinimum(1)
        self.spinBoxHAmount.setMaximum(999999999)
        self.spinBoxHAmount.setObjectName("spinBoxHAmount")
        self.gridLayout.addWidget(self.spinBoxHAmount, 1, 4, 1, 1)
        self.gridLayout_2.addWidget(self.groupBox_2, 1, 0, 1, 2)
        spacerItem = QtWidgets.QSpacerItem(519, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 2, 0, 1, 1)
        self.pushButtonGO = QtWidgets.QPushButton(FormCrop)
        self.pushButtonGO.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setObjectName("pushButtonGO")
        self.gridLayout_2.addWidget(self.pushButtonGO, 2, 1, 1, 1)

        self.retranslateUi(FormCrop)
        QtCore.QMetaObject.connectSlotsByName(FormCrop)

    def retranslateUi(self, FormCrop):
        _translate = QtCore.QCoreApplication.translate
        FormCrop.setWindowTitle(_translate("FormCrop", "Crop"))
        self.groupBox.setTitle(_translate("FormCrop", "Image"))
        self.groupBox_2.setTitle(_translate("FormCrop", "Amount"))
        self.label.setText(_translate("FormCrop", "X"))
        self.label_2.setText(_translate("FormCrop", "Y"))
        self.label_3.setText(_translate("FormCrop", "W"))
        self.label_4.setText(_translate("FormCrop", "H"))
        self.pushButtonGO.setText(_translate("FormCrop", ":go"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormCrop = QtWidgets.QWidget()
    ui = Ui_FormCrop()
    ui.setupUi(FormCrop)
    FormCrop.show()
    sys.exit(app.exec_())
