# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'arithmetic.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormArithmetic(object):
    def setupUi(self, FormArithmetic):
        FormArithmetic.setObjectName("FormArithmetic")
        FormArithmetic.resize(364, 191)
        self.gridLayout_4 = QtWidgets.QGridLayout(FormArithmetic)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.comboOperation = QtWidgets.QComboBox(FormArithmetic)
        self.comboOperation.setObjectName("comboOperation")
        self.comboOperation.addItem("")
        self.comboOperation.addItem("")
        self.comboOperation.addItem("")
        self.comboOperation.addItem("")
        self.comboOperation.addItem("")
        self.comboOperation.addItem("")
        self.gridLayout_4.addWidget(self.comboOperation, 0, 0, 1, 1)
        self.tabWidget = QtWidgets.QTabWidget(FormArithmetic)
        self.tabWidget.setMinimumSize(QtCore.QSize(0, 102))
        self.tabWidget.setMaximumSize(QtCore.QSize(16777215, 102))
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.tab)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.doubleSpinBoxValue = QtWidgets.QDoubleSpinBox(self.tab)
        self.doubleSpinBoxValue.setDecimals(4)
        self.doubleSpinBoxValue.setMinimum(-1e+60)
        self.doubleSpinBoxValue.setMaximum(1e+60)
        self.doubleSpinBoxValue.setObjectName("doubleSpinBoxValue")
        self.gridLayout_3.addWidget(self.doubleSpinBoxValue, 0, 0, 1, 1)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.tab_2)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.labelFile = QtWidgets.QLabel(self.tab_2)
        self.labelFile.setText("")
        self.labelFile.setObjectName("labelFile")
        self.gridLayout_2.addWidget(self.labelFile, 0, 0, 1, 2)
        spacerItem = QtWidgets.QSpacerItem(235, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 1, 0, 1, 1)
        self.pushButtonGetFile = QtWidgets.QPushButton(self.tab_2)
        self.pushButtonGetFile.setObjectName("pushButtonGetFile")
        self.gridLayout_2.addWidget(self.pushButtonGetFile, 1, 1, 1, 1)
        self.tabWidget.addTab(self.tab_2, "")
        self.gridLayout_4.addWidget(self.tabWidget, 1, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem1, 2, 0, 1, 1)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        spacerItem2 = QtWidgets.QSpacerItem(268, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem2, 0, 0, 1, 1)
        self.pushButtonGO = QtWidgets.QPushButton(FormArithmetic)
        self.pushButtonGO.setMinimumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setMaximumSize(QtCore.QSize(80, 25))
        self.pushButtonGO.setObjectName("pushButtonGO")
        self.gridLayout.addWidget(self.pushButtonGO, 0, 1, 1, 1)
        self.gridLayout_4.addLayout(self.gridLayout, 3, 0, 1, 1)

        self.retranslateUi(FormArithmetic)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(FormArithmetic)

    def retranslateUi(self, FormArithmetic):
        _translate = QtCore.QCoreApplication.translate
        FormArithmetic.setWindowTitle(_translate("FormArithmetic", "Arithmetic"))
        self.comboOperation.setItemText(0, _translate("FormArithmetic", "+ Add"))
        self.comboOperation.setItemText(1, _translate("FormArithmetic", "- Subtract"))
        self.comboOperation.setItemText(2, _translate("FormArithmetic", "* Multiply"))
        self.comboOperation.setItemText(3, _translate("FormArithmetic", "/ Divide"))
        self.comboOperation.setItemText(4, _translate("FormArithmetic", "^ Power"))
        self.comboOperation.setItemText(5, _translate("FormArithmetic", "% Mod"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("FormArithmetic", "Absolute Value"))
        self.pushButtonGetFile.setText(_translate("FormArithmetic", "Open..."))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("FormArithmetic", "File"))
        self.pushButtonGO.setText(_translate("FormArithmetic", ":go"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormArithmetic = QtWidgets.QWidget()
    ui = Ui_FormArithmetic()
    ui.setupUi(FormArithmetic)
    FormArithmetic.show()
    sys.exit(app.exec_())
