# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'hselect.ui'
#
# Created by: PyQt5 UI code generator 5.15.11
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_FormHSelect(object):
    def setupUi(self, FormHSelect):
        FormHSelect.setObjectName("FormHSelect")
        FormHSelect.resize(657, 651)
        self.gridLayout_2 = QtWidgets.QGridLayout(FormHSelect)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.groupBox = QtWidgets.QGroupBox(FormHSelect)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.tableWidgetHeaders = QtWidgets.QTableWidget(self.groupBox)
        self.tableWidgetHeaders.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.tableWidgetHeaders.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableWidgetHeaders.setObjectName("tableWidgetHeaders")
        self.tableWidgetHeaders.setColumnCount(3)
        self.tableWidgetHeaders.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetHeaders.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetHeaders.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidgetHeaders.setHorizontalHeaderItem(2, item)
        self.gridLayout.addWidget(self.tableWidgetHeaders, 0, 0, 1, 1)
        self.gridLayout_2.addWidget(self.groupBox, 0, 0, 1, 2)
        spacerItem = QtWidgets.QSpacerItem(342, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem, 1, 0, 1, 1)
        self.pushButtonExport = QtWidgets.QPushButton(FormHSelect)
        self.pushButtonExport.setObjectName("pushButtonExport")
        self.gridLayout_2.addWidget(self.pushButtonExport, 1, 1, 1, 1)

        self.retranslateUi(FormHSelect)
        QtCore.QMetaObject.connectSlotsByName(FormHSelect)

    def retranslateUi(self, FormHSelect):
        _translate = QtCore.QCoreApplication.translate
        FormHSelect.setWindowTitle(_translate("FormHSelect", "HSelect"))
        self.groupBox.setTitle(_translate("FormHSelect", "Header"))
        item = self.tableWidgetHeaders.horizontalHeaderItem(0)
        item.setText(_translate("FormHSelect", "Key"))
        item = self.tableWidgetHeaders.horizontalHeaderItem(1)
        item.setText(_translate("FormHSelect", "Value"))
        item = self.tableWidgetHeaders.horizontalHeaderItem(2)
        item.setText(_translate("FormHSelect", "Comment"))
        self.pushButtonExport.setText(_translate("FormHSelect", "Export"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    FormHSelect = QtWidgets.QWidget()
    ui = Ui_FormHSelect()
    ui.setupUi(FormHSelect)
    FormHSelect.show()
    sys.exit(app.exec_())
